@@ -1,5 +1,7 @@
 from collections import OrderedDict
 import re
+import warnings
+
 from cqlengine import columns
 from cqlengine.exceptions import ModelException, CQLEngineException, ValidationError
 from cqlengine.query import ModelQuerySet, DMLQuery, AbstractQueryableColumn
@@ -11,7 +13,10 @@ class ModelDefinitionException(ModelException): pass
 
 class PolyMorphicModelException(ModelException): pass
 
-DEFAULT_KEYSPACE = 'cqlengine'
+DEFAULT_KEYSPACE = None
+
+class UndefinedKeyspaceWarning(Warning):
+    pass
 
 
 class hybrid_classmethod(object):
@@ -256,8 +261,18 @@ class BaseModel(object):
     #__ttl__ = None # this doesn't seem to be used
     __consistency__ = None # can be set per query
 
-    __read_repair_chance__ = 0.1
-
+    # Additional table properties
+    __bloom_filter_fp_chance__ = None
+    __caching__ = None
+    __comment__ = None
+    __dclocal_read_repair_chance__ = None
+    __default_time_to_live__ = None
+    __gc_grace_seconds__ = None
+    __index_interval__ = None
+    __memtable_flush_period_in_ms__ = None
+    __populate_io_cache_on_flush__ = None
+    __read_repair_chance__ = None
+    __replicate_on_write__ = None
 
     _timestamp = None # optional timestamp to include with the operation (USING TIMESTAMP)
 
@@ -490,6 +505,9 @@ class BaseModel(object):
 
     @classmethod
     def filter(cls, *args, **kwargs):
+        # if kwargs.values().count(None):
+        #     raise CQLEngineException("Cannot pass None as a filter")
+
         return cls.objects.filter(*args, **kwargs)
 
     @classmethod
@@ -743,6 +761,7 @@ class ModelMetaClass(type):
 
         #create the class and add a QuerySet to it
         klass = super(ModelMetaClass, cls).__new__(cls, name, bases, attrs)
+
         return klass
 
 
