@@ -293,7 +293,7 @@ class AbstractQuerySet(object):
         if self._batch:
             raise CQLEngineException("Only inserts, updates, and deletes are available in batch mode")
         if self._result_cache is None:
-            self._result_cache = self._execute(self._select_query())
+            self._result_cache = list(self._execute(self._select_query()))
             self._construct_result = self._get_result_constructor()
 
     def _fill_result_cache_to_idx(self, idx):
@@ -405,6 +405,9 @@ class AbstractQuerySet(object):
         :rtype: AbstractQuerySet
         """
         #add arguments to the where clause filters
+        if kwargs.values().count(None):
+            raise CQLEngineException("None values on filter are not allowed")
+
         clone = copy.deepcopy(self)
         for operator in args:
             if not isinstance(operator, WhereClause):
@@ -631,7 +634,7 @@ class ModelQuerySet(AbstractQuerySet):
         #check that there's either a = or IN relationship with a primary key or indexed field
         equal_ops = [self.model._columns.get(w.field) for w in self._where if isinstance(w.operator, EqualsOperator)]
         token_comparison = any([w for w in self._where if isinstance(w.value, Token)])
-        if not any([w.primary_key or w.index for w in equal_ops]) and not token_comparison:
+        if not any([w.primary_key or w.index for w in equal_ops]) and not token_comparison and not self._allow_filtering:
             raise QueryException('Where clauses require either a "=" or "IN" comparison with either a primary key or indexed field')
 
         if not self._allow_filtering:
