@@ -1,9 +1,10 @@
 from uuid import uuid4
+import warnings
 from cqlengine.query import QueryException, ModelQuerySet, DMLQuery
 from cqlengine.tests.base import BaseCassEngTestCase
 
 from cqlengine.exceptions import ModelException, CQLEngineException
-from cqlengine.models import Model, ModelDefinitionException, ColumnQueryEvaluator
+from cqlengine.models import Model, ModelDefinitionException, ColumnQueryEvaluator, UndefinedKeyspaceWarning
 from cqlengine import columns
 import cqlengine
 
@@ -19,6 +20,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         """
 
         class TestModel(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             text = columns.Text()
 
@@ -40,6 +42,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         -the db_map allows columns
         """
         class WildDBNames(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             content = columns.Text(db_field='words_and_whatnot')
             numbers = columns.Integer(db_field='integers_etc')
@@ -64,6 +67,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         """
 
         class Stuff(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             words = columns.Text()
             content = columns.Text()
@@ -74,6 +78,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
     def test_exception_raised_when_creating_class_without_pk(self):
         with self.assertRaises(ModelDefinitionException):
             class TestModel(Model):
+                __keyspace__ = 'test'
                 count   = columns.Integer()
                 text    = columns.Text(required=False)
 
@@ -83,6 +88,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         Tests that instance value managers are isolated from other instances
         """
         class Stuff(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             num = columns.Integer()
 
@@ -98,6 +104,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         Tests that fields defined on the super class are inherited properly
         """
         class TestModel(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             text = columns.Text()
 
@@ -110,6 +117,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
     def test_column_family_name_generation(self):
         """ Tests that auto column family name generation works as expected """
         class TestModel(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             text = columns.Text()
 
@@ -145,6 +153,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
         Test compound partition key definition
         """
         class ModelWithPartitionKeys(cqlengine.Model):
+            __keyspace__ = 'test'
             id = columns.UUID(primary_key=True, default=lambda:uuid4())
             c1 = cqlengine.Text(primary_key=True)
             p1 = cqlengine.Text(partition_key=True)
@@ -166,6 +175,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
     def test_del_attribute_is_assigned_properly(self):
         """ Tests that columns that can be deleted have the del attribute """
         class DelModel(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
             key = columns.Integer(primary_key=True)
             data = columns.Integer(required=False)
@@ -179,9 +189,11 @@ class TestModelClassFunction(BaseCassEngTestCase):
         """ Tests that DoesNotExist exceptions are not the same exception between models """
 
         class Model1(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
 
         class Model2(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
 
         try:
@@ -195,6 +207,7 @@ class TestModelClassFunction(BaseCassEngTestCase):
     def test_does_not_exist_inherits_from_superclass(self):
         """ Tests that a DoesNotExist exception can be caught by it's parent class DoesNotExist """
         class Model1(Model):
+            __keyspace__ = 'test'
             id  = columns.UUID(primary_key=True, default=lambda:uuid4())
 
         class Model2(Model1):
@@ -208,6 +221,14 @@ class TestModelClassFunction(BaseCassEngTestCase):
         except Exception:
             assert False, "Model2 exception should not be caught by Model1"
 
+    def test_abstract_model_keyspace_warning_is_skipped(self):
+        with warnings.catch_warnings(record=True) as warn:
+            class NoKeyspace(Model):
+                __abstract__ = True
+                key = columns.UUID(primary_key=True)
+
+        self.assertEqual(len(warn), 0)
+
 class TestManualTableNaming(BaseCassEngTestCase):
 
     class RenamedTest(cqlengine.Model):
@@ -223,12 +244,14 @@ class TestManualTableNaming(BaseCassEngTestCase):
 
 class AbstractModel(Model):
     __abstract__ = True
+    __keyspace__ = 'test'
 
 class ConcreteModel(AbstractModel):
     pkey = columns.Integer(primary_key=True)
     data = columns.Integer()
 
 class AbstractModelWithCol(Model):
+    __keyspace__ = 'test'
     __abstract__ = True
     pkey = columns.Integer(primary_key=True)
 
@@ -237,6 +260,7 @@ class ConcreteModelWithCol(AbstractModelWithCol):
 
 class AbstractModelWithFullCols(Model):
     __abstract__ = True
+    __keyspace__ = 'test'
     pkey = columns.Integer(primary_key=True)
     data = columns.Integer()
 
@@ -262,9 +286,9 @@ class TestAbstractModelClasses(BaseCassEngTestCase):
 
     def test_attempting_to_create_abstract_table_fails(self):
         """ Attempting to create a table from an abstract model should fail """
-        from cqlengine.management import create_table
+        from cqlengine.management import sync_table
         with self.assertRaises(CQLEngineException):
-            create_table(AbstractModelWithFullCols)
+            sync_table(AbstractModelWithFullCols)
 
     def test_attempting_query_on_abstract_model_fails(self):
         """ Tests attempting to execute query with an abstract model fails """
@@ -279,8 +303,8 @@ class TestAbstractModelClasses(BaseCassEngTestCase):
 
     def test_concrete_class_table_creation_cycle(self):
         """ Tests that models with inherited abstract classes can be created, and have io performed """
-        from cqlengine.management import create_table, delete_table
-        create_table(ConcreteModelWithCol)
+        from cqlengine.management import sync_table, drop_table
+        sync_table(ConcreteModelWithCol)
 
         w1 = ConcreteModelWithCol.create(pkey=5, data=6)
         w2 = ConcreteModelWithCol.create(pkey=6, data=7)
@@ -293,7 +317,7 @@ class TestAbstractModelClasses(BaseCassEngTestCase):
         assert w2.pkey == r2.pkey
         assert w2.data == r2.data
 
-        delete_table(ConcreteModelWithCol)
+        drop_table(ConcreteModelWithCol)
 
 
 class TestCustomQuerySet(BaseCassEngTestCase):
@@ -309,6 +333,7 @@ class TestCustomQuerySet(BaseCassEngTestCase):
 
         class CQModel(Model):
             __queryset__ = QSet
+            __keyspace__ = 'test'
             part = columns.UUID(primary_key=True)
             data = columns.Text()
 
@@ -322,6 +347,7 @@ class TestCustomQuerySet(BaseCassEngTestCase):
                 raise self.TestException
 
         class CDQModel(Model):
+            __keyspace__ = 'test'
             __dmlquery__ = DMLQ
             part = columns.UUID(primary_key=True)
             data = columns.Text()
