@@ -35,8 +35,8 @@ class SelectStatementTests(TestCase):
     def test_count(self):
         ss = SelectStatement('table', count=True, limit=10, order_by='d')
         ss.add_where_clause(WhereClause('a', EqualsOperator(), 'b'))
-        self.assertEqual(unicode(ss), 'SELECT COUNT(*) FROM table WHERE "a" = %(0)s', unicode(ss))
-        self.assertNotIn('LIMIT', unicode(ss))
+        self.assertEqual(unicode(ss), 'SELECT COUNT(*) FROM table WHERE "a" = %(0)s LIMIT 10', unicode(ss))
+        self.assertIn('LIMIT', unicode(ss))
         self.assertNotIn('ORDER', unicode(ss))
 
     def test_context(self):
